
# Type: cell line to thing association_subject




URI: [biolink:cell_line_to_thing_association_subject](https://w3id.org/biolink/vocab/cell_line_to_thing_association_subject)


## Domain and Range

[CellLineToThingAssociation](CellLineToThingAssociation.md) ->  <sub>REQ</sub> [CellLine](CellLine.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [CellLineToThingAssociation](CellLineToThingAssociation.md)
